## 0.7.3.1 (2022-11-21)

Finish `slumber` annotations (#9237)

## 0.7.3 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 0.7.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

